@@ -28,6 +28,8 @@ if '-h' not in sys.argv and len(sys.argv) > 1:
     sys.argv.append('-b')
     ROOT.gErrorIgnoreLevel = ROOT.kWarning
     sys.argv.remove('-b')
+    if os.path.exists('rootlogon.C'):
+        ROOT.gROOT.Macro('rootlogon.C')
 
 
 ######## Define classes and generators #######################################
@@ -245,11 +247,11 @@ def process_hist_matplotlib(path, new_path, files, obj):
         else:               fmt = 'o'
         stack.add(hist, label=file.name, color=options.colors[i], fmt=fmt)
     if (options.errorbar):
-        plots = stack.plot_errorbar(replace=options.replace, yerr=True)
+        plots = stack.errorbar(replace=options.replace, yerr=True)
     if options.stack:
-        stack.plot_barstack(replace=options.replace)
+        stack.barstack(replace=options.replace)
     if options.bar:
-        stack.plot_bar(replace=options.replace, alpha=0.5)
+        stack.bar(replace=options.replace, alpha=0.5)
     if options.efficiency:
         plt.ylim(0, 1)
     if options.logx: ax.set_xscale('log')
@@ -526,7 +528,7 @@ Note: By default, this script will work completely in ROOT.  If you use the
 ##                       "styles are taken from overlayHists_config.py in the "
 ##                       "root2matplot distribution or the current directory")
     parser.add_option('--efficiency-from', default=None, metavar="DENOM",
-                      help="Divide all plots by DENOM")
+                      help="Divide all plots by the hitsogram in path DENOM")
     group1 = optparse.OptionGroup(
         parser,
         "special plotting options",
